==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/bulletins/state/bulletin-board/bulletin-board.selectors.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { createSelector } from '@ngrx/store';
import { BulletinsState, selectBulletinState } from '../index';
import { bulletinBoardFeatureKey, BulletinBoardState } from './index';

export const selectBulletinBoardState = createSelector(
    selectBulletinState,
    (state: BulletinsState) => state[bulletinBoardFeatureKey]
);

export const selectLastBulletinId = createSelector(
    selectBulletinBoardState,
    (state: BulletinBoardState) => state.lastBulletinId
);

export const selectBulletinBoardFilter = createSelector(
    selectBulletinBoardState,
    (state: BulletinBoardState) => state.filter
);

export const selectStatus = createSelector(selectBulletinBoardState, (state: BulletinBoardState) => state.status);

==> nifi-2.7.0-source-release.zip: nifi-2.7.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/bulletins/state/bulletin-board/bulletin-board.selectors.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { createSelector } from '@ngrx/store';
import { BulletinsState, selectBulletinState } from '../index';
import { bulletinBoardFeatureKey, BulletinBoardState } from './index';

export const selectBulletinBoardState = createSelector(
    selectBulletinState,
    (state: BulletinsState) => state[bulletinBoardFeatureKey]
);

export const selectLastBulletinId = createSelector(
    selectBulletinBoardState,
    (state: BulletinBoardState) => state.lastBulletinId
);

export const selectBulletinBoardFilter = createSelector(
    selectBulletinBoardState,
    (state: BulletinBoardState) => state.filter
);

export const selectLoadedTimestamp = createSelector(
    selectBulletinBoardState,
    (state: BulletinBoardState) => state.loadedTimestamp
);
